@@ -1,25 +1,25 @@
 import random
-import uuid
-
 import textwrap
-from urllib.parse import quote as urlquote, unquote as urlunquote
-
-import hypothesis.strategies as st
-from hypothesis import given
+import uuid
+from urllib.parse import quote as urlquote
+from urllib.parse import unquote as urlunquote
 
 import pytest
 
+from .. import assert_item_equals
+from .. import EVENT_TEMPLATE
+from .. import normalize_item
+from .. import TASK_TEMPLATE
+from .. import VCARD_TEMPLATE
 from vdirsyncer import exceptions
 from vdirsyncer.storage.base import normalize_meta_value
 from vdirsyncer.vobject import Item
 
-from .. import EVENT_TEMPLATE, TASK_TEMPLATE, VCARD_TEMPLATE, \
-    assert_item_equals, normalize_item, printable_characters_strategy
-
 
 def get_server_mixin(server_name):
     from . import __name__ as base
-    x = __import__('{}.servers.{}'.format(base, server_name), fromlist=[''])
+
+    x = __import__(f"{base}.servers.{server_name}", fromlist=[""])
     return x.ServerMixin
 
 
@@ -34,18 +34,18 @@ class StorageTests:
     supports_collections = True
     supports_metadata = True
 
-    @pytest.fixture(params=['VEVENT', 'VTODO', 'VCARD'])
+    @pytest.fixture(params=["VEVENT", "VTODO", "VCARD"])
     def item_type(self, request):
-        '''Parametrize with all supported item types.'''
+        """Parametrize with all supported item types."""
         return request.param
 
     @pytest.fixture
     def get_storage_args(self):
-        '''
+        """
         Return a function with the following properties:
 
         :param collection: The name of the collection to create and use.
-        '''
+        """
         raise NotImplementedError()
 
     @pytest.fixture
@@ -55,9 +55,9 @@ class StorageTests:
     @pytest.fixture
     def get_item(self, item_type):
         template = {
-            'VEVENT': EVENT_TEMPLATE,
-            'VTODO': TASK_TEMPLATE,
-            'VCARD': VCARD_TEMPLATE,
+            "VEVENT": EVENT_TEMPLATE,
+            "VTODO": TASK_TEMPLATE,
+            "VCARD": VCARD_TEMPLATE,
         }[item_type]
 
         return lambda **kw: format_item(template, **kw)
@@ -65,12 +65,12 @@ class StorageTests:
     @pytest.fixture
     def requires_collections(self):
         if not self.supports_collections:
-            pytest.skip('This storage does not support collections.')
+            pytest.skip("This storage does not support collections.")
 
     @pytest.fixture
     def requires_metadata(self):
         if not self.supports_metadata:
-            pytest.skip('This storage does not support metadata.')
+            pytest.skip("This storage does not support metadata.")
 
     def test_generic(self, s, get_item):
         items = [get_item() for i in range(1, 10)]
@@ -96,7 +96,7 @@ class StorageTests:
         href, etag = s.upload(get_item())
         if etag is None:
             _, etag = s.get(href)
-        (href2, item, etag2), = s.get_multi([href] * 2)
+        ((href2, item, etag2),) = s.get_multi([href] * 2)
         assert href2 == href
         assert etag2 == etag
 
@@ -129,7 +129,7 @@ class StorageTests:
     def test_update_nonexisting(self, s, get_item):
         item = get_item()
         with pytest.raises(exceptions.PreconditionFailed):
-            s.update('huehue', item, '"123"')
+            s.update("huehue", item, '"123"')
 
     def test_wrong_etag(self, s, get_item):
         item = get_item()
@@ -146,7 +146,7 @@ class StorageTests:
 
     def test_delete_nonexisting(self, s, get_item):
         with pytest.raises(exceptions.PreconditionFailed):
-            s.delete('1', '"123"')
+            s.delete("1", '"123"')
 
     def test_list(self, s, get_item):
         assert not list(s.list())
@@ -156,10 +156,10 @@ class StorageTests:
         assert list(s.list()) == [(href, etag)]
 
     def test_has(self, s, get_item):
-        assert not s.has('asd')
+        assert not s.has("asd")
         href, etag = s.upload(get_item())
         assert s.has(href)
-        assert not s.has('asd')
+        assert not s.has("asd")
         s.delete(href, etag)
         assert not s.has(href)
 
@@ -172,8 +172,8 @@ class StorageTests:
             info[href] = etag
 
         assert {
-            href: etag for href, item, etag
-            in s.get_multi(href for href, etag in info.items())
+            href: etag
+            for href, item, etag in s.get_multi(href for href, etag in info.items())
         } == info
 
     def test_repr(self, s, get_storage_args):
@@ -183,80 +183,76 @@ class StorageTests:
     def test_discover(self, requires_collections, get_storage_args, get_item):
         collections = set()
         for i in range(1, 5):
-            collection = 'test{}'.format(i)
+            collection = f"test{i}"
             s = self.storage_class(**get_storage_args(collection=collection))
             assert not list(s.list())
             s.upload(get_item())
             collections.add(s.collection)
 
         actual = {
-            c['collection'] for c in
-            self.storage_class.discover(**get_storage_args(collection=None))
+            c["collection"]
+            for c in self.storage_class.discover(**get_storage_args(collection=None))
         }
 
         assert actual >= collections
 
-    def test_create_collection(self, requires_collections, get_storage_args,
-                               get_item):
-        if getattr(self, 'dav_server', '') in \
-           ('icloud', 'fastmail', 'davical'):
-            pytest.skip('Manual cleanup would be necessary.')
-        if getattr(self, 'dav_server', '') == "radicale":
+    def test_create_collection(self, requires_collections, get_storage_args, get_item):
+        if getattr(self, "dav_server", "") in ("icloud", "fastmail", "davical"):
+            pytest.skip("Manual cleanup would be necessary.")
+        if getattr(self, "dav_server", "") == "radicale":
             pytest.skip("Radicale does not support collection creation")
 
         args = get_storage_args(collection=None)
-        args['collection'] = 'test'
+        args["collection"] = "test"
 
-        s = self.storage_class(
-            **self.storage_class.create_collection(**args)
-        )
+        s = self.storage_class(**self.storage_class.create_collection(**args))
 
         href = s.upload(get_item())[0]
-        assert href in {href for href, etag in s.list()}
+        assert href in (href for href, etag in s.list())
 
-    def test_discover_collection_arg(self, requires_collections,
-                                     get_storage_args):
-        args = get_storage_args(collection='test2')
+    def test_discover_collection_arg(self, requires_collections, get_storage_args):
+        args = get_storage_args(collection="test2")
         with pytest.raises(TypeError) as excinfo:
             list(self.storage_class.discover(**args))
 
-        assert 'collection argument must not be given' in str(excinfo.value)
+        assert "collection argument must not be given" in str(excinfo.value)
 
     def test_collection_arg(self, get_storage_args):
-        if self.storage_class.storage_name.startswith('etesync'):
-            pytest.skip('etesync uses UUIDs.')
+        if self.storage_class.storage_name.startswith("etesync"):
+            pytest.skip("etesync uses UUIDs.")
 
         if self.supports_collections:
-            s = self.storage_class(**get_storage_args(collection='test2'))
+            s = self.storage_class(**get_storage_args(collection="test2"))
             # Can't do stronger assertion because of radicale, which needs a
             # fileextension to guess the collection type.
-            assert 'test2' in s.collection
+            assert "test2" in s.collection
         else:
             with pytest.raises(ValueError):
-                self.storage_class(collection='ayy', **get_storage_args())
+                self.storage_class(collection="ayy", **get_storage_args())
 
     def test_case_sensitive_uids(self, s, get_item):
-        if s.storage_name == 'filesystem':
-            pytest.skip('Behavior depends on the filesystem.')
+        if s.storage_name == "filesystem":
+            pytest.skip("Behavior depends on the filesystem.")
 
         uid = str(uuid.uuid4())
         s.upload(get_item(uid=uid.upper()))
         s.upload(get_item(uid=uid.lower()))
-        items = list(href for href, etag in s.list())
+        items = [href for href, etag in s.list()]
         assert len(items) == 2
         assert len(set(items)) == 2
 
-    def test_specialchars(self, monkeypatch, requires_collections,
-                          get_storage_args, get_item):
-        if getattr(self, 'dav_server', '') == 'radicale':
-            pytest.skip('Radicale is fundamentally broken.')
-        if getattr(self, 'dav_server', '') in ('icloud', 'fastmail'):
-            pytest.skip('iCloud and FastMail reject this name.')
+    def test_specialchars(
+        self, monkeypatch, requires_collections, get_storage_args, get_item
+    ):
+        if getattr(self, "dav_server", "") == "radicale":
+            pytest.skip("Radicale is fundamentally broken.")
+        if getattr(self, "dav_server", "") in ("icloud", "fastmail"):
+            pytest.skip("iCloud and FastMail reject this name.")
 
-        monkeypatch.setattr('vdirsyncer.utils.generate_href', lambda x: x)
+        monkeypatch.setattr("vdirsyncer.utils.generate_href", lambda x: x)
 
-        uid = 'test @ foo ät bar град сатану'
-        collection = 'test @ foo ät bar'
+        uid = "test @ foo ät bar град сатану"
+        collection = "test @ foo ät bar"
 
         s = self.storage_class(**get_storage_args(collection=collection))
         item = get_item(uid=uid)
@@ -267,55 +263,66 @@ class StorageTests:
             assert etag2 == etag
             assert_item_equals(item2, item)
 
-        (_, etag3), = s.list()
+        ((_, etag3),) = s.list()
         assert etag2 == etag3
 
         # etesync uses UUIDs for collection names
-        if self.storage_class.storage_name.startswith('etesync'):
+        if self.storage_class.storage_name.startswith("etesync"):
             return
 
         assert collection in urlunquote(s.collection)
-        if self.storage_class.storage_name.endswith('dav'):
-            assert urlquote(uid, '/@:') in href
+        if self.storage_class.storage_name.endswith("dav"):
+            assert urlquote(uid, "/@:") in href
 
     def test_metadata(self, requires_metadata, s):
-        if not getattr(self, 'dav_server', ''):
-            assert not s.get_meta('color')
-            assert not s.get_meta('displayname')
+        if not getattr(self, "dav_server", ""):
+            assert not s.get_meta("color")
+            assert not s.get_meta("displayname")
 
         try:
-            s.set_meta('color', None)
-            assert not s.get_meta('color')
-            s.set_meta('color', '#ff0000')
-            assert s.get_meta('color') == '#ff0000'
+            s.set_meta("color", None)
+            assert not s.get_meta("color")
+            s.set_meta("color", "#ff0000")
+            assert s.get_meta("color") == "#ff0000"
         except exceptions.UnsupportedMetadataError:
             pass
 
-        for x in ('hello world', 'hello wörld'):
-            s.set_meta('displayname', x)
-            rv = s.get_meta('displayname')
+        for x in ("hello world", "hello wörld"):
+            s.set_meta("displayname", x)
+            rv = s.get_meta("displayname")
             assert rv == x
             assert isinstance(rv, str)
 
-    @given(value=st.one_of(
-        st.none(),
-        printable_characters_strategy
-    ))
+    @pytest.mark.parametrize(
+        "value",
+        [
+            None,
+            "",
+            "Hello there!",
+            "Österreich",
+            "中国",
+            "한글",
+            "42a4ec99-b1c2-4859-b142-759112f2ca50",
+            "فلسطين",
+        ],
+    )
     def test_metadata_normalization(self, requires_metadata, s, value):
-        x = s.get_meta('displayname')
+        x = s.get_meta("displayname")
         assert x == normalize_meta_value(x)
 
-        if not getattr(self, 'dav_server', None):
+        if not getattr(self, "dav_server", None):
             # ownCloud replaces "" with "unnamed"
-            s.set_meta('displayname', value)
-            assert s.get_meta('displayname') == normalize_meta_value(value)
+            s.set_meta("displayname", value)
+            assert s.get_meta("displayname") == normalize_meta_value(value)
 
     def test_recurring_events(self, s, item_type):
-        if item_type != 'VEVENT':
-            pytest.skip('This storage instance doesn\'t support iCalendar.')
+        if item_type != "VEVENT":
+            pytest.skip("This storage instance doesn't support iCalendar.")
 
         uid = str(uuid.uuid4())
-        item = Item(textwrap.dedent('''
+        item = Item(
+            textwrap.dedent(
+                """
         BEGIN:VCALENDAR
         VERSION:2.0
         BEGIN:VEVENT
@@ -349,7 +356,11 @@ class StorageTests:
         TRANSP:OPAQUE
         END:VEVENT
         END:VCALENDAR
-        '''.format(uid=uid)).strip())
+        """.format(
+                    uid=uid
+                )
+            ).strip()
+        )
 
         href, etag = s.upload(item)
 
