@@ -1,8 +1,7 @@
 import pytest
 
-from vdirsyncer.storage.singlefile import SingleFileStorage
-
 from . import StorageTests
+from vdirsyncer.storage.singlefile import SingleFileStorage
 
 
 class TestSingleFileStorage(StorageTests):
@@ -12,10 +11,10 @@ class TestSingleFileStorage(StorageTests):
 
     @pytest.fixture
     def get_storage_args(self, tmpdir):
-        def inner(collection='test'):
-            rv = {'path': str(tmpdir.join('%s.txt')),
-                  'collection': collection}
+        def inner(collection="test"):
+            rv = {"path": str(tmpdir.join("%s.txt")), "collection": collection}
             if collection is not None:
                 rv = self.storage_class.create_collection(**rv)
             return rv
+
         return inner
