@@ -1,10 +1,12 @@
-from hypothesis import HealthCheck, given, settings
-
 import pytest
+from hypothesis import given
+from hypothesis import HealthCheck
+from hypothesis import settings
 
 from tests import uid_strategy
-
-from vdirsyncer.repair import IrreparableItem, repair_item, repair_storage
+from vdirsyncer.repair import IrreparableItem
+from vdirsyncer.repair import repair_item
+from vdirsyncer.repair import repair_storage
 from vdirsyncer.storage.memory import MemoryStorage
 from vdirsyncer.utils import href_safe
 from vdirsyncer.vobject import Item
@@ -16,14 +18,8 @@ from vdirsyncer.vobject import Item
 def test_repair_uids(uid):
     s = MemoryStorage()
     s.items = {
-        'one': (
-            'asdf',
-            Item('BEGIN:VCARD\nFN:Hans\nUID:{}\nEND:VCARD'.format(uid))
-        ),
-        'two': (
-            'asdf',
-            Item('BEGIN:VCARD\nFN:Peppi\nUID:{}\nEND:VCARD'.format(uid))
-        )
+        "one": ("asdf", Item(f"BEGIN:VCARD\nFN:Hans\nUID:{uid}\nEND:VCARD")),
+        "two": ("asdf", Item(f"BEGIN:VCARD\nFN:Peppi\nUID:{uid}\nEND:VCARD")),
     }
 
     uid1, uid2 = [s.get(href)[0].uid for href, etag in s.list()]
@@ -40,7 +36,7 @@ def test_repair_uids(uid):
 @settings(suppress_health_check=HealthCheck.all())
 def test_repair_unsafe_uids(uid):
     s = MemoryStorage()
-    item = Item('BEGIN:VCARD\nUID:{}\nEND:VCARD'.format(uid))
+    item = Item(f"BEGIN:VCARD\nUID:{uid}\nEND:VCARD")
     href, etag = s.upload(item)
     assert s.get(href)[0].uid == uid
     assert not href_safe(uid)
@@ -53,12 +49,11 @@ def test_repair_unsafe_uids(uid):
     assert href_safe(newuid)
 
 
-@pytest.mark.parametrize('uid,href', [
-    ('b@dh0mbr3', 'perfectly-fine'),
-    ('perfectly-fine', 'b@dh0mbr3')
-])
+@pytest.mark.parametrize(
+    "uid,href", [("b@dh0mbr3", "perfectly-fine"), ("perfectly-fine", "b@dh0mbr3")]
+)
 def test_repair_unsafe_href(uid, href):
-    item = Item('BEGIN:VCARD\nUID:{}\nEND:VCARD'.format(uid))
+    item = Item(f"BEGIN:VCARD\nUID:{uid}\nEND:VCARD")
     new_item = repair_item(href, item, set(), True)
     assert new_item.raw != item.raw
     assert new_item.uid != item.uid
@@ -66,18 +61,14 @@ def test_repair_unsafe_href(uid, href):
 
 
 def test_repair_do_nothing():
-    item = Item('BEGIN:VCARD\nUID:justfine\nEND:VCARD')
-    assert repair_item('fine', item, set(), True) is item
-    assert repair_item('@@@@/fine', item, set(), True) is item
+    item = Item("BEGIN:VCARD\nUID:justfine\nEND:VCARD")
+    assert repair_item("fine", item, set(), True) is item
+    assert repair_item("@@@@/fine", item, set(), True) is item
 
 
-@pytest.mark.parametrize('raw', [
-    'AYYY',
-    '',
-    '@@@@',
-    'BEGIN:VCARD',
-    'BEGIN:FOO\nEND:FOO'
-])
+@pytest.mark.parametrize(
+    "raw", ["AYYY", "", "@@@@", "BEGIN:VCARD", "BEGIN:FOO\nEND:FOO"]
+)
 def test_repair_irreparable(raw):
     with pytest.raises(IrreparableItem):
-        repair_item('fine', Item(raw), set(), True)
+        repair_item("fine", Item(raw), set(), True)
